/**
 * All client-side components built on the SharePoint framework need a valid component manifest. This interface
 * represents properties that are required by all types of client-side components like Applications and Web Parts.
 * Component specific manifests will extend this interface to add properties required by that component type.
 *
 * @remarks
 *
 * The schema of this manifest is owned and versioned by Microsoft. Following rules should be followed while changing
 * this schema. This set of rules can also be called the "manifest upgrade rules".
 *
 * - For minor changes, new properties can be added to this schema in a backwards-compatible way. i.e. the code
 *   that processes the manifest should be able to handle the absence of those new properties.
 *
 * - Try to model your changes as minor SemVer increments.  Major version changes should be avoided because they
 *   impose a migration cost on developers.
 *
 * - The `'manifestVersion'` should be bumped for all small or big changes.
 *
 * @privateRemarks
 *
 * This schema should be at all times kept in sync with the server-side code file
 * SPClientSideComponentManifest.cs.
 *
 * @public
 */ export { };

//#sourceMappingUrl=./IClientSideComponentManifest.js.map